pyprofibus - PROFIBUS-DP stack
==============================

pyprofibus is a [PROFIBUS-DP](https://en.wikipedia.org/wiki/Profibus)
stack written in Python.

Dependencies
------------

* Python 2.7 or Python 3.x: [python.org](https://www.python.org/)

License
-------
Copyright (c) 2013-2016 Michael Buesch <m@bues.ch>

Licensed under the terms of the GNU General Public License version 2,
or (at your option) any later version.
